@@ -1,4 +1,4 @@
-/* tpb - program to use the IBM ThinkPad (tm) special keys
+/* tpb - program to use the IBM ThinkPad(tm) special keys
  * Copyright (C) 2002 Markus Braun <markus.braun@krawel.de>
  *
  * This file is part of tpb.
@@ -18,16 +18,39 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#ifndef __TPB_H__
+#define __TPB_H__
+
 #define POLLTIME 1000
+#define NVRAMDEV "/dev/nvram"
+#ifdef HAVE_LIBXOSD
+#define OSDFONT "-*-lucidatypewriter-medium-r-normal-*-*-250-*-*-*-*-*-*"
+#define OSDCOLOR "BLUE"
+#define OSDTIMEOUT 3
+#define OSDPOS XOSD_bottom
+#define OSDOFFSET 25
+#endif /* HAVE_LIBXOSD */
 
 typedef struct {
-	char tpb; /* ThinkPad Button */
-	char kl;  /* KeyboardLight */
-	char ds;  /* Display State */
-	char bl;  /* Brightness Level */
-	char vl;  /* Volume Level */
-	char ms;  /* Mute State */
+	char tpb; /* ThinkPad button */
+	char kt;  /* ThinkLight */
+	char ht;  /* hibernation/suspend toggle */
+	char ds;  /* display state */
+	char bl;  /* brightness level */
+	char bt;  /* brightness toggle */
+	char vl;  /* volume level */
+	char vt;  /* volume toggle */
+	char mt;  /* mute toggle */
+	char ac;  /* ac connected */
+	char pma; /* power management mode ac */
+	char pmb; /* power management mode battery */
 } t_tpb;
 
 void print_usage(const char *prog);
 int get_state(t_tpb *tpbs);
+int fork_app(char *cmd);
+
+#endif /* __TPB_H__*/
+
+/* vim:set sw=2:set ts=2: */
+/* vim600:set fen:set fdm=marker:set fdl=0: */
